#ifndef UDFREADWRITE_H
#define UDFREADWRITE_H

#include <QObject>
#include "udfburn_global.h"

class UdfReadWriteImpl;

namespace UdfBurn {

class UDFBURN_EXPORT UdfReadWrite : public QObject
{
    Q_OBJECT
public:
    explicit UdfReadWrite(QString device, QObject *parent = nullptr);
    ~UdfReadWrite();


    /**
     * @brief 启动udfclient，设置一些初始化操作
     * @param errinfo ：(输出参数)提供给调用者的错误信息
     * @return : 初始化是否成功
     * @retval : true 初始化成功
     * @retval : false 初始化失败
     */
    bool startUdfClient(char **errinfo);

    /**
     * @brief 判断光盘是否正在刻录数据
     * @return : 光盘是否刻录中
     * @retval : true 光盘正在刻录
     * @retval : false 光盘没有刻录
     */
    bool isDiscRunning();


    /**
     * @brief 同步数据及释放内存
     */
    void closeUdfClient();

    /**
     * @brief 写单个数据
     * @param errinfo ：(输出参数)提供给调用者的错误信息
     * @param source_filename ：(输入参数)源文件的绝对路径，如"/home/wcl/test.txt"
     * @param dest_dir ：(输入参数)指定数据写入到光盘中哪个目录,默认为空
     * @return ：写操作是否成功
     * @retval : false 写单个数据失败，errinfo返回错误信息
     * @retval : true 写单个数据成功
     */
    bool writeSingleData(char **errinfo, QString source_filename, QString dest_dir=QString());

    /**
     * @brief 写多个数据
     * @param errinfo (输出参数)提供给调用者的错误信息
     * @param fileList (输入参数)多个源文件的绝对路径
     * @param dest_dir (输出参数)指定数据写入到光盘中哪个目录，默认为空
     * @return 写数据是否成功
     * @retval false 写多个数据失败，errinfo返回错误信息
     * @retval true 写多个数据成功
     */
    bool writeMultiData(char **errinfo, QStringList fileList, QString dest_dir=QString());

    /**
     * @brief 文件(夹)重命名
     * @param old_filename (输入参数)光盘中要改名的文件(夹)名
     * @param new_filename (输入参数)新的文件(夹)名
     * @param errinfo（输出参数）提供给调用者的错误信息
     * @return 重命名过程是否成功
     * @retval ture 重命名成功
     * @retval false 重命名失败，errinfo返回错误信息
     */
    bool changeFileName(QString old_filename, QString new_filename, char **errinfo);

    /**
     * @brief 创建文件夹
     * @param dirname (输入参数)文件夹名字
     * @param errinfo (输出参数)提供给调用者的错误信息
     * @return 创建文件夹是否成功
     * @retval false 创建文件夹成功，errinfo返回错误信息
     * @retval true 创建文件夹失败
     */
    bool createDir(QString dirname, char **errinfo);

    /**
     * @brief 删除文件
     * @param fileList (输入参数)要移除的文件列表,如删除 "abc/def/hi.txt"文件，需要传输"abc/def/hi.txt"
     * @param errinfo (输出参数)提供给调用者的错误信息
     * @return 移除数据是否成功
     * @retval false 移除文件失败，errinfo返回错误信息
     */
    bool removeFile(QStringList fileList, char **errinfo);

private:
    UdfReadWriteImpl * m_impl;

};

}

#endif // UDFREADWRITE_H
